package com.zipcodewilmington.phonebook;

import java.util.HashMap;
import java.util.Map;
import java.util.TreeMap;
import java.util.ArrayList;

public class PhoneBook {

    //a map to hold every persons information
    private Map<String, ArrayList<String>> book = new HashMap<>();
    private ArrayList<String> alphaArray = new ArrayList<>();
    //final to represent an error if the key or value does not exist
    final static String entryErr = "No such entry exists";

    //a method to check if an entry exists in the book field
    public boolean hasEntry(String name) {
        if(book.containsKey(name)){
            return true;
        }
        return false;
    }

    public void addEntry(String name, ArrayList<String> numbers) {
        this.book.put(name, numbers);
    }

    public String lookUp(String name) {
        //store the resulting string - all numbers this person has
        String result = "";
        //if this name is an entry
        if(hasEntry(name))
        {
            //create a new arrayList to store the list of numbers
            ArrayList<String> returnNumbers = book.get(name);
            //for each number this person has
            for(String number : returnNumbers){
                //add it to a string seperate by spaces
                result += number + " ";
            }
            //trim the ending and leading spaces
            result = result.trim();
            //return the result after trimming
            return result;
        }
        //if the entry does not exist, return an error;
        return entryErr;
    }

    public void remove(String name) {
        if(hasEntry(name)){
            book.remove(name);
        }
    }

    public String reverseLookUp(String number) {
        //loop through every key in the book
        for(String key : book.keySet())
        {
            //store the numbers for the current person
            ArrayList<String> numbers = book.get(key);
            //loop through each number this person has
            for(String num : numbers){
                //if the current number in the loop, is the same as the number being searched
                if(num.equals(number)){
                    //return this perosns name
                    return key;
                }
            }
        }

        return entryErr;
    }

    public void printAlpha() {
        //create a new TreeMap to alphabatize the entries
        Map<String, ArrayList<String>> alphabeticalBook = new TreeMap<>(book);
        //loop through each key
        for(String key : alphabeticalBook.keySet())
        {
            String contactCard = key + " ";
            //grab the list of numbers for the person at this iteration
            ArrayList<String> numbers = alphabeticalBook.get(key);
            //for each number they have,
            for(String number : numbers){
                //add it to the string seperated by a space
                contactCard += number + " ";
            }
            //trim the ending and leading white space from the contact card string
            contactCard = contactCard.trim();
            //add the string to the array to test if they are printed alphateically
            alphaArray.add(contactCard);
            //print the contact card
            System.out.println(contactCard);
        }
    }
    //accessor function to return the alphabatized list of entries
    public ArrayList<String> getAlphatizedArray() {
        return alphaArray;
    }
    //accessor function to return the amount of entries thus far
    public int getSize(){
        return book.size();
    }
}
